window.Gleam.initSearch([{"doc":"glacier","title":"glacier","content":"# Glacier · Gleam Incremental Interactive Unit Testing\n\n[![Hex Package](https://img.shields.io/hexpm/v/glacier?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glacier)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glacier/)\n[![Licence](https://img.shields.io/hexpm/l/glacier?color=ffaff3&amp;label=%F0%9F%93%83)](https://github.com/inoas/glacier/blob/main/LICENCE)\n\n**Glacier** brings incremental interactive unit testing to\n[Gleam](https://gleam.run). It is meant as a drop-in replacement for\n[gleeunit](https://hexdocs.pm/gleeunit) and depends on a fork of it.\n\n&lt;figure&gt;\n\t&lt;img src=&quot;https://raw.githubusercontent.com/inoas/glacier/main/glacier-logo.png&quot; alt=&quot;Glacier Logo&quot; style=&quot;max-height: 33vh; width: auto; height: auto&quot; width=&quot;480&quot; height=&quot;480&quot;/&gt;\n  &lt;figcaption&gt;&lt;i&gt;&lt;small&gt;Glacier: &lt;a href=&quot;https://en.wikipedia.org/wiki/Glacier&quot;&gt;«A persistent body of dense ice that is constantly moving under its own weight.»&lt;/a&gt;&lt;/small&gt;&lt;/i&gt;&lt;/figcaption&gt;\n&lt;/figure&gt;\n\n## Installation\n\n1. Run:\n\n   ```shell\n   gleam remove gleeunit\n   gleam add glacier --dev\n   gleam clean\n   ```\n\n2. Open `YOUR_GlEAM_PROJECT/test/YOUR_GLEAM_PROJECT.gleam` and replace `import gleeunit` with\n  `import glacier` and `gleeunit.main()` with `glacier.main()` (or alias glacier as gleeunit).\n3. If you want to run on **Deno 1.40+** open `gleam.toml` and add:\n\n   ```toml\n   [javascript.deno]\n   allow_read = [&quot;./&quot;]\n   allow_net = [&quot;deno.land&quot;]\n   allow_run = [&quot;gleam&quot;]\n   ```\n\n## Usage\n\n1. Run any one of these, of which some are synonyms:\n   - `gleam test --target erlang -- --glacier`\n   - `gleam test --target erl -- --glacier`\n   - `gleam test --target javascript --runtime deno -- --glacier`\n   - `gleam test --target javascript --runtime nodejs -- --glacier`\n   - `gleam test --target js --runtime node -- --glacier`\n2. Save gleam module within your projects `src` or `test` gleam directory and\n   watch associated tests to re-run.\n\n*Notice: On Linux [**inotify**](https://en.wikipedia.org/wiki/Inotify) must be installed.*\n\n## Upgrading Glacier\n\nMake sure to run `gleam clean` after upgrading Glacier as a dependency.\n\n## Improvements over gleeunit\n\n**Glacier** differs from **gleeunit** insofar, that it let&#39;s you:\n\n1. Pass in the `glacier` flag like so: `gleam test -- --glacier`, save a gleam\n   module and only related test modules will rerun.\n2. Or pass in a specific unit test modules to rerun, for example:\n   `gleam test -- test/my_module_test.gleam`.\n3. If `gleam test` is passed without any `--`-arguments it behaves the same as\n   **gleeunit**.\n4. You can still pass in target or runtime flags, such as `--target javascript`\n   `--runtime deno`, aka:\n   - `gleam test --target javascript --runtime deno -- --glacier`\n   - `gleam test --target javascript --runtime deno -- test/my_module_test.gleam`.\n   - `gleam test --target js --runtime deno -- test/my_module_test.gleam`.\n\n*Note: `gleam test` must only be executed from the base project directory!*\n\n### Testing against Erlang, NodeJS and Deno simultaneously\n\nRun these in 3 terminals side by side:\n\n- `gleam test -- --glacier # this implies --target erlang`\n- `gleam test --target js --runtime node -- --glacier`\n- `gleam test --target js --runtime deno -- --glacier`\n\n## Requirements &amp; Installation\n\n### Requirements\n\nRequires Gleam 1.0.0 or later.\n\n#### Target specific requirements\n\n- Erlang/OTP 25 (lower may or may not run)\n- NodeJS 18 LTS+ (lower may or may not run)\n- Deno v1.30.0+ (lower does not run)\n\n#### Target Erlang\n\nDevelopment and testing only happens on very recent stable Erlang/OTP versions, and thus may or may not run on previous versions.\n\nDepends on [fs](https://hexdocs.pm/fs/):\n\n- Linux [relies](https://github.com/synrc/fs#backends) on [**inotify**](https://en.wikipedia.org/wiki/Inotify).\n- Mac: Should work out of the box.\n- Windows: Should work out of the box.\n\n#### Target JavaScript/NodeJS/Deno\n\nDevelopment and testing only happens on very recent NodeJS LTS versions, and thus may or may not run on previous versions.\n\nDepends on [NodeJS:`fsPromises.watch`](https://nodejs.org/api/fs.html#fspromiseswatchfilename-options) or [`Deno.watchFs`](https://deno.land/api@v1.30.0?s=Deno.watchFs):\n\n- Linux: [relies](https://nodejs.org/docs/latest-v18.x/api/fs.html#fs_caveats) on [**inotify**](https://en.wikipedia.org/wiki/Inotify).\n- Mac: Should work out of the box.\n- Windows: Should work out of the box.\n\n## Documentation\n\nDocumentation can be found at &lt;https://hexdocs.pm/glacier&gt;.\n\n## Contributing to Glacier\n\nSee [DEVELOPMENT.md](./DEVELOPMENT.md).\n\n## License\n\n[Apache 2.0](./LICENCE)\n","url":"index.html"},{"doc":"glacier","title":"glacier","content":"# Changelog\n\n## 1.1.0\n\n- Updated upstream gleeunit dependency to 1.2.0 (glacier_gleeunit 1.2.1001).\n- Update simplifile dep to &gt;- 2.0.0.\n\n## 1.0.0\n\n- Updates glacier_gleeunit dependency to up to date version.\n\n## 0.10.0\n\n- Updates Glacier for Gleam 1.0.\n\n## 0.9.0\n\n- Syntax updates.\n\n## 0.8.1\n\n- Improve readme\n- Hide internal modules from docs\n- Improve docs\n\n## 0.8.0\n\n- Upgraded to be in line with gleam 0.27.0\n\n## 0.7.0 - skipped\n\n## 0.6.2\n\n- Add docs on how to run glacier with deno\n\n## 0.6.1\n\n- Attempt to fix deno testing.\n\n## 0.6.0\n\n- With Gleam 0.26 supporting *Deno*, so does Glacier\n\n## 0.5.0\n\n- Added fixes and work arounds so that glacier runs with Gleam 0.26.0\n- Glacier might run on Deno might (or might not) run once Gleam 0.26.1 is out\n\n## 0.4.1\n\n- Fix readme.\n\n## 0.4.0\n\n- Remove internal verbatim copy to `gleeunit` and depend on a fork:\n  [`glacier_gleeunit`](https://hex.pm/glacier_gleeunit).\n\n## 0.3.1\n\n- Fix Changelog.\n\n## 0.3.0\n\n- Fix detection of unqualified imports.\n- Fix detection of aliased imports.\n- Fix detection of renames.\n- Files with white spaces are now ignored.\n- Improved readme.\n- Force rebased on `lpil/gleeunit` to keep all contributor history alive.\n  - This was required because initially `Glacier` was supposed to depend on\n    a patched `Gleeunit`, but the idea of patching `Gleeunit` a bit was\n    rejected by the `Gleeunit` team. While this may not be strictly necessary\n    this honors previous contributions transparently.\n  - This was a quick and dirty process where I saved a lot of time by _not_\n    fixing any merges and instead just adding them without touching them\n    including the diff noise. As a consequence single commits if checked out\n    might not run any more. After the dirty rebase I&#39;ve commited the\n    source code state equvialent to `0.2.7` to restore functionality.\n- Proper BE noun instead of an AE one for the `LICENCE` file and naming.\n\n## 0.2.7\n\n- Fix `MaxListenersExceededWarning: Possible EventEmitter memory leak detected` (#4).\n- Cleanup `README.md`.\n\n## 0.2.6\n\n- Instruct to use `gleam add glacier --dev` to add as a dev dependency, only.\n\n## 0.2.5\n\n- Readme: Explain that `gleeunit` is optional if `glacier` is installed if `gleeunit/should` is replaced by `glacier/should`.\n\n## 0.2.4\n\n- More compatibility changes to run `glacier` alongside `gleeunit`:\n  Added `glacier/should` which is a renamed `gleeunit/should`.\n\n## 0.2.3\n\n- Remove code that did nothing.\n\n## 0.2.2\n\n- Fixed `README.md`.\n\n## 0.2.1\n\n- Fixed `README.md`.\n\n## 0.2.0\n\n- Added `CHANGELOG.md`.\n- Renamed internal gleeunit fork to gleeunit2 to avoid collisions.\n- JavaScript: File renames are picked up by the watcher.\n- Replaced `glacier.run()` with `glacier.main()` as latter did not make sense before.\n- Fixed `README.md`.\n- Fixed the logo to work across hexpm and github and shields badges.\n\n## 0.1.0\n\n- _Ex post_ rebased on `lpil/gleeunit`\n\n### Gleeunit v0.8\n\n- `should.be_ok` and `should.be_error` now unwrap the result argument\n\n### Gleeunit v0.7.2 - 2022-11-19\n\n- Update for Gleam v0.25.0.\n\n### Gleeunit v0.7.1 - 2022-11-11\n\n- Fixed a bug where project names containing numbers would not run correctly on\n  JavaScript.\n\n### Gleeunit v0.7.0 - 2022-09-24\n\n- Line numbers are printed on JS for assertions.\n\n### Gleeunit v0.6.2 - 2022-07-15\n\n- Fixed a bug where assertions in JavaScript tests could fail to report an\n  error due to them being async.\n\n### Gleeunit v0.6.1 - 2022-01-26\n\n- Fixed a bug where failed tests on the JavaScript target would crash the `main`\n  function.\n- Fixed a bug where tests on the JavaScript target could succeed regardless of\n  return value.\n\n### Gleeunit v0.6.0 - 2022-01-09\n\n- Added support for OTP versions below 23.\n- Added support for running tests on the JavaScript target.\n\n### Gleeunit v0.5.0 - 2021-12-05\n\n- Updated for Gleam v0.18.0.\n- Added `gleeunit/should` module containing assertions.\n\n### Gleeunit v0.4.0 - 2021-11-01\n\n- Slightly improved failure format.\n\n### Gleeunit v0.3.0 - 2021-10-31\n\n- Fixed Hex package which was missing some files.\n\n### Gleeunit v0.2.0 - 2021-10-31\n\n- `gleeunit.discover_and_run_tests` removed.\n- `gleeunit.main` added.\n\n### Gleeunit v0.1.0 - 2021-10-31\n\n- Initial release.\n","url":"changelog.html"},{"doc":"glacier","title":"glacier","content":"# Glacier · Contribution Guide\n\nThis package heavily depends on a [gleeunit](https://github.com/lpil/gleeunit) fork called [glacier_gleeunit](https://github.com/inoas/gleeunit)!\n\n## Improving Glacier\n\n```shell\ngit clone https://github.com/inoas/glacier.git\ncd glacier\n```\n\nSee all [open issues](https://github.com/inoas/glacier/issues) on GitHub if you want to help out.\n\n## How does it work?\n\n1. `gleam test` passes through `glacier.main()` and simply executes `gleeunit.main()` as if **gleeunit** was used directly.\n2. `gleam test -- test_module_a test_module_b` passes through `glacier.main()` and executes `gleeunit.test_modules(modules_list)` where `modules_list` is `[&quot;foo&quot;, &quot;bar&quot;]`. The given modules are checked if they exist as either `.gleam` or `.erl` test module files and then **gleeunit** runs these test modules.\n3. `gleam test -- --glacier` enters `glacier.main()` and starts a file watcher: Upon changes in module files in `./test` it just passes those through as `gleam test -- changed_test_module`(so re-saving test files executes the single test), and if a module file in `./src` got changed it parses that changed module file for any imported modules and puts the module and all chained imported modules in a distinct list of modules that should be tested. Then all test module files are read and imports of those are gathered one by one and cross matched against that list. The result is a list of test modules that need to be run, which then gets done by executing a shell call similar to `gleam test -- detected_test_module_a detected_test_module_b detected_test_module_c etc`, aka jump to step `2`.\n\n### Demo for target Erlang\n\n```shell\n# Traditional test runs\ngleam test --target erlang\ngleam test --target erlang -- test/glacier_demo/glacier_demo_module_a_test.gleam\n\n# Incremental interactive test\ngleam test --target erlang -- --glacier\n# Re-save ./src/glacier_demo/glacier_demo_module_a.gleam\n```\n\n### Demo for target JavaScript on NodeJS\n\n```shell\n# Traditional test runs\ngleam test --target javascript --runtime node\ngleam test --target javascript --runtime node -- test/glacier_demo/glacier_demo_module_a_test.gleam\n\n# Incremental interactive test\ngleam test --target javascript --runtime node -- --glacier\n# Re-save ./src/glacier_demo/glacier_demo_module_a.gleam\n```\n\nNotice: You may omit `--runtime node` as it is currently set as the default runtime for target `javascript`.\n\n### Demo for target JavaScript on Deno\n\n```shell\n# Traditional test runs\ngleam test --target javascript --runtime deno\ngleam test --target javascript --runtime deno -- test/glacier_demo/glacier_demo_module_a_test.gleam\n\n# Incremental interactive test\ngleam test --target javascript --runtime deno -- --glacier\n# Re-save ./src/glacier_demo/glacier_demo_module_a.gleam\n```\n\n#### Privileges required for Deno\n\nDo not forget to edit `gleam.toml` to add deno privileges:\n\n```toml\n[javascript.deno]\nallow_read = [&quot;./&quot;]\nallow_net = [&quot;deno.land&quot;]\nallow_run = [&quot;gleam&quot;]\n```\n\n### Caveats\n\nIn line with gleam module name requirements:\n\n- `./src` and `./test` source files with white spaces will not pass detection.\n- Behavior towards `./src` and `./test` source files with non-alphanumeric characters is not tested, and generally unsupported.\n","url":"contribute.html"},{"doc":"glacier","title":"glacier","content":"                                 Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      &quot;License&quot; shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      &quot;Legal Entity&quot; shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      &quot;control&quot; means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      &quot;Source&quot; form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      &quot;Object&quot; form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      &quot;Work&quot; shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      &quot;Contribution&quot; shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, &quot;submitted&quot;\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;\n\n      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n","url":"licence.html"},{"doc":"glacier","title":"ModuleKind","content":"pub type ModuleKind {\n  SrcModuleKind\n  TestModuleKind\n}\n Atom to internally differentiate between `src` and `test` modules.\n Public because the FFIs rely on it.\n\nSrcModuleKind\n\n\nTestModuleKind\n\n\nSynonyms:\nglacier.ModuleKind\nglacier ModuleKind","url":"glacier.html#ModuleKind"},{"doc":"glacier","title":"main","content":"pub fn main() -&gt; Nil\n Runs either `glacier` or `gleeunit` bundled as `gleeunit`, depending on\n the given command line arguments.\n\nSynonyms:\nglacier.main\nglacier main","url":"glacier.html#main"},{"doc":"glacier","title":"glacier","content":"","url":"glacier.html"},{"doc":"glacier/should","title":"be_error","content":"pub fn be_error(result: Result(a, b)) -&gt; b\n\nSynonyms:\nglacier/should.be_error\nglacier/should be_error","url":"glacier/should.html#be_error"},{"doc":"glacier/should","title":"be_false","content":"pub fn be_false(actual: Bool) -&gt; Nil\n\nSynonyms:\nglacier/should.be_false\nglacier/should be_false","url":"glacier/should.html#be_false"},{"doc":"glacier/should","title":"be_none","content":"pub fn be_none(a: Option(a)) -&gt; Nil\n\nSynonyms:\nglacier/should.be_none\nglacier/should be_none","url":"glacier/should.html#be_none"},{"doc":"glacier/should","title":"be_ok","content":"pub fn be_ok(result: Result(a, b)) -&gt; a\n\nSynonyms:\nglacier/should.be_ok\nglacier/should be_ok","url":"glacier/should.html#be_ok"},{"doc":"glacier/should","title":"be_some","content":"pub fn be_some(a: Option(a)) -&gt; a\n\nSynonyms:\nglacier/should.be_some\nglacier/should be_some","url":"glacier/should.html#be_some"},{"doc":"glacier/should","title":"be_true","content":"pub fn be_true(actual: Bool) -&gt; Nil\n\nSynonyms:\nglacier/should.be_true\nglacier/should be_true","url":"glacier/should.html#be_true"},{"doc":"glacier/should","title":"equal","content":"pub fn equal(a: a, b: a) -&gt; Nil\n\nSynonyms:\nglacier/should.equal\nglacier/should equal","url":"glacier/should.html#equal"},{"doc":"glacier/should","title":"fail","content":"pub fn fail() -&gt; Nil\n\nSynonyms:\nglacier/should.fail\nglacier/should fail","url":"glacier/should.html#fail"},{"doc":"glacier/should","title":"not_equal","content":"pub fn not_equal(a: a, b: a) -&gt; Nil\n\nSynonyms:\nglacier/should.not_equal\nglacier/should not_equal","url":"glacier/should.html#not_equal"},{"doc":"glacier/should","title":"glacier/should","content":" A proxy module into gleeunit/should\n\n If you are consistently using glacier (which wraps gleeunit) instead of\n gleeunit you may replace all `import gleeunit/should` with\n `import glacier/should`.","url":"glacier/should.html"}]);